# CVPM - Computer Vision Package Manager

[简体中文](https://cvpm.autoai.org/zh-CN/guide/)

[![Go Report Card](https://goreportcard.com/badge/github.com/unarxiv/cvpm)](https://goreportcard.com/report/github.com/unarxiv/cvpm)
[![Build Status](https://travis-ci.org/unarxiv/CVPM.svg?branch=master)](https://travis-ci.org/unarxiv/CVPM)
[![GitHub issues](https://img.shields.io/github/issues/unarxiv/cvpm.svg?style=flat-square)](https://github.com/unarxiv/cvpm/issues)
[![GitHub license](https://img.shields.io/github/license/unarxiv/cvpm.svg?style=flat-square)](https://github.com/unarxiv/CVPM/blob/master/LICENSE)
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Funarxiv%2FCVPM.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Funarxiv%2FCVPM?ref=badge_shield)
[![Gitter chat](https://badges.gitter.im/gitterHQ/gitter.png)](https://gitter.im/unarxiv/cvpm)
[![Maintainability](https://api.codeclimate.com/v1/badges/d66183d5e7ed7d8f0ca2/maintainability)](https://codeclimate.com/github/unarxiv/CVPM/maintainability)
[![BCH compliance](https://bettercodehub.com/edge/badge/unarxiv/CVPM?branch=master)](https://bettercodehub.com/)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/2343/badge)](https://bestpractices.coreinfrastructure.org/projects/2343)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/unarxiv/CVPM.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/unarxiv/CVPM/alerts/)
[![Language grade: JavaScript](https://img.shields.io/lgtm/grade/javascript/g/unarxiv/CVPM.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/unarxiv/CVPM/context:javascript)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/unarxiv/CVPM.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/unarxiv/CVPM/context:python)

## Introduction

CVPM is a package manager for computer vision. It helps you to download, install and run a computer vision service.

[![asciicast](https://asciinema.org/a/YRgOSy1a7WwdPyK77PEgE12Kl.png)](https://asciinema.org/a/YRgOSy1a7WwdPyK77PEgE12Kl)

## Documentation

Full documentation can be found [here](https://cvpm.autoai.org).

## Contributing

If you found a security bugs, please do not post it in issues or any other public forum. You can send me [email](mailto:xiaozhe.yaoi@qq.com) directly.

## Contributors
[![](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/images/0)](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/links/0)[![](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/images/1)](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/links/1)[![](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/images/2)](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/links/2)[![](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/images/3)](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/links/3)[![](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/images/4)](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/links/4)[![](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/images/5)](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/links/5)[![](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/images/6)](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/links/6)[![](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/images/7)](https://sourcerer.io/fame/xzyaoi/unarxiv/CVPM/links/7)


## Affiliated Project

This project is inspired from [CVTron](https://docs.cvtron.org).

## FAQs

Q: Where can I find useful models?

A: There are three places. The first one, which is we recommend most, is our [model hub](https://hub.autoai.org), where you can download, purchase, search models. The second one is GitHub, in GiHub, you can search for CVPM_Available in readme file, which indicates that repository is compatible with CVPM. The third one is our [forum](https://forum.cvtron.xyz), where you can discuss performance of models, and ask for others models.

## License
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Funarxiv%2FCVPM.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Funarxiv%2FCVPM?ref=badge_large)
